@@ -69,6 +69,151 @@ class WebConnection(Session):
         response.raise_for_status()
         return response.json()
 
+    def get_searches(
+        self, page=1, per_page=10, sort_by="created_at", sort_order="DESC"
+    ):
+        """
+        {
+           "code":200,
+           "status":"success",
+           "data":{
+              "filters":{
+                 "q":"\/data\/searches",
+                 "page":"1",
+                 "perPage":"1",
+                 "sort_by":"created_at",
+                 "sort_order":"DESC"
+              },
+              "searches":[
+                 {
+                    "id":123456789,
+                    "name":"123456789-dc9dMXGG",
+                    "status":"new",
+                    "searcher_id":10000,
+                    "assignee_id":10000,
+                    "filters":{
+                       "birth_year":1900,
+                       "country_codes":["NL"],
+                       "entity_type":"person",
+                       "remove_deceased":0,
+                       "sources":[],
+                       "types":[
+                          "sanction",
+                          "warning",
+                          "fitness-probity",
+                          "pep",
+                          "pep-class-1",
+                          "pep-class-2",
+                          "pep-class-3",
+                          "pep-class-4"
+                       ]
+                    },
+                    "match_status":"potential_match",
+                    "risk_level":"unknown",
+                    "search_term":"Max Jones",
+                    "total_hits":2,
+                    "created_at":"2020-10-14T14:45:38.062000",
+                    "updated_at":"2020-10-14T14:45:38.062000",
+                    "searcher":{
+                       "id":10000,
+                       "name":"Compliance"
+                    },
+                    "types":["pep-class-2", "fitness-probity","pep"],
+                    "grouped_types":[
+                       {"type":"sanction"},
+                       {"type":"warning"},
+                       {"type":"fitness-probity"},
+                       {
+                          "type":"pep",
+                          "subtypes":["pep-class-1","pep-class-2","pep-class-3","pep-class-4"]
+                       }
+                    ],
+                    "ref":{
+                       "entity_statuses":[],
+                       "client_ref":"abcdefgh-84b8-47dc-9db5-c0e0fc47889a"
+                    },
+                    "assignee":{
+                       "id":10000,
+                       "name":"Compliance"
+                    },
+                    "comments":[],
+                    "is_monitored":false,
+                    "monitored":{
+                       "entity_changes":null,
+                       "changed_at":[],
+                       "has_changed":false,
+                       "is_monitored":false,
+                       "suspended_at":null
+                    },
+                    "tags":[
+                       {
+                          "id":1234567890,
+                          "search_id":1234567890,
+                          "name":"investor_url",
+                          "color":"#f5d328",
+                          "tag_id":1234,
+                          "display":1,
+                          "value":"https:\/\/google.nl\/",
+                          "created_at":"2020-10-14T14:45:38.063000"
+                       },
+                       {
+                          "id":0987654321,
+                          "search_id":987654321,
+                          "name":"user_url",
+                          "color":"#dcbd23",
+                          "tag_id":4321,
+                          "display":1,
+                          "value":"https:\/\/google.nl\/",
+                          "created_at":"2020-10-14T14:45:38.063000"
+                       }
+                    ]
+                 }
+              ],
+              "hasNextPage":true
+           }
+        }
+
+        :param page:
+        :param per_page:
+        :param sort_by:
+        :param sort_order:
+        :return:
+        """
+        response = self.get(
+            f"{self.url}/data/searches",
+            params={
+                "page": page,
+                "perPage": per_page,
+                "sort_by": sort_by,
+                "sort_order": sort_order,
+            },
+        )
+        response.raise_for_status()
+        return response.json()["data"]
+
+    def get_searches_count(
+        self, page=1, per_page=10, sort_by="created_at", sort_order="DESC"
+    ):
+        """
+        response {"code":200,"status":"success","data":{"total_searches":8659,"total_pages":866,"per_page":"10","current_page":"1"}}
+        :param page:
+        :param per_page:
+        :param sort_by:
+        :param sort_order:
+        :return:
+        """
+        response = self.get(
+            f"{self.url}/data/searches/count",
+            params={
+                "page": page,
+                "perPage": per_page,
+                "sort_by": sort_by,
+                "sort_order": sort_order,
+            },
+        )
+        response.raise_for_status()
+        return response.json()["data"]
+
 
 class ApiConnection(Session):
     def __init__(
@@ -249,7 +394,7 @@ class ApiConnection(Session):
         }
         response = self.patch(
             f"{self.url}/searches/{search_id}",
-            data=request_data,
+            json=request_data,
         )
         response.raise_for_status()
         return response.json()["content"]["data"]
@@ -280,7 +425,7 @@ class ApiConnection(Session):
         }
         response = self.patch(
             f"{self.url}/searches/{search_id}/entities",
-            data=request_data,
+            json=request_data,
         )
         response.raise_for_status()
         return response.json()["content"]["data"]
@@ -313,7 +458,7 @@ class ApiConnection(Session):
         }
         response = self.patch(
             f"{self.url}/searches/{search_id}/monitors",
-            data=request_data,
+            json=request_data,
         )
         response.raise_for_status()
         return response.json()["content"]
